{% extends "picata/base.html" %}

{% block title %}Page not found{% endblock %}

{% block body_class %}template-404{% endblock %}

{% block content %}
<h1>Page not found</h1>

<h2>Sorry, this page could not be found.</h2>
{% endblock %}
