{% load wagtailcore_tags %}

{% if value.heading %}<h{{ value.heading_level|default:"2" }}>{{ value.heading }}</h{{ value.heading_level|default:"2" }}>{% endif %}
<ul class="icon-link-list">{% for item in value.items %}{% include_block item %}{% endfor %}</ul>
