{% extends "picata/dl_view.html" %}

{% block definitions %}
  <dt><p><a href="#what-is-lorem-ipsum">What is Lorem Ipsum?</a></p></dt>
  <dd><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Praesent justo leo, dapibus non ultricies sit amet, sagittis a mauris. Aliquam nec dolor arcu. Nullam sollicitudin venenatis commodo. Morbi aliquet venenatis felis, et condimentum sem sodales nec. Etiam at risus tellus. Orci varius natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus. Etiam et lobortis purus. Vestibulum nisi sem, feugiat eget auctor vel, scelerisque et dui.</p></dd>
  <dt><p><a href="#where-does-it-come-from">Where does it come from?</a></p></dt>
  <dd><p>Donec tincidunt eros justo, sit amet luctus mauris condimentum eu. Nam posuere ultrices turpis, ut facilisis velit ultricies in. Sed at risus sed purus pellentesque aliquam sed nec est. Sed non nisi id neque bibendum bibendum at vitae ligula. Integer eget dapibus velit, eu pulvinar nisl. Duis lobortis arcu ex. Aenean fermentum maximus interdum. Curabitur sit amet bibendum nisi, a cursus risus. Curabitur at metus eget nibh consequat viverra. Cras rhoncus finibus urna, efficitur viverra tellus molestie et. Sed nec vulputate erat. Vestibulum nec nunc condimentum, ultrices ipsum in, hendrerit quam. Integer felis erat, placerat eget libero eu, mollis sagittis mauris. Aenean sed lacus id orci accumsan porttitor. Etiam aliquet nunc et consectetur scelerisque.</p></dd>
  <dt><p><a href="#why-do-we-use-it">Why do we use it?</a></p></dt>
  <dd><p>Donec ac urna quis justo mollis porta. Nunc sit amet risus at nulla vestibulum mattis. Donec sit amet ante bibendum, elementum elit nec, congue arcu. Fusce eu porttitor justo. Pellentesque feugiat nunc id neque tristique hendrerit eu porta orci. Aenean et magna aliquam nibh elementum pharetra. Donec ornare, dui eget blandit semper, risus est hendrerit nulla, vulputate eleifend felis augue vitae diam. Proin suscipit eros turpis, et mattis libero sollicitudin non. Mauris iaculis est sed neque volutpat, vel posuere dui cursus.</p></dd>
{% endblock %}
